@@ -165,7 +165,7 @@ char cregestring[1024];
 #define cregSetAttrComponentPath(attr, cid, path) \
 { \
   if (!declare_component(attr, cid, path)) { \
-    sprintf(cregestring, "Component %s with path %s declared twice" \
+    snprintf(cregestring, 1024, "Component %s with path %s declared twice" \
             " (or internal error)", cid_name(cid), path); \
     cl_free(path); \
     cregerror(cregestring); \
@@ -1670,7 +1670,7 @@ yyreduce:
 #line 259 "registry.y"
     { 
                                       if ((cregattrib = setup_attribute(cregcorpus, (yyvsp[(2) - (2)].strval), ATT_POS, NULL)) == NULL) {
-                                        sprintf(cregestring, 
+                                        snprintf(cregestring, 1024,
                                                 "Positional attribute %s declared twice -- "
                                                 "semantic error", (yyvsp[(2) - (2)].strval));
                                         cl_free((yyvsp[(2) - (2)].strval));
@@ -1687,7 +1687,7 @@ yyreduce:
   case 30:
 #line 271 "registry.y"
     { if (((yyval.attr) = setup_attribute(cregcorpus, (yyvsp[(2) - (3)].strval), ATT_ALIGN, NULL)) == NULL) {
-                                        sprintf(cregestring, "Alignment attribute %s declared twice -- "
+                                        snprintf(cregestring, 1024, "Alignment attribute %s declared twice -- "
                                                 "semantic error", (yyvsp[(2) - (3)].strval));
                                         cl_free((yyvsp[(2) - (3)].strval));
                                         cl_free((yyvsp[(3) - (3)].storage).path);
@@ -1701,7 +1701,7 @@ yyreduce:
   case 31:
 #line 282 "registry.y"
     { if (((yyval.attr) = setup_attribute(cregcorpus, (yyvsp[(2) - (3)].strval), ATT_STRUC, NULL)) == NULL) {
-                                        sprintf(cregestring, "Structure attribute %s declared twice -- "
+                                        snprintf(cregestring, 1024, "Structure attribute %s declared twice -- "
                                                 "semantic error", (yyvsp[(2) - (3)].strval));
                                         cl_free((yyvsp[(2) - (3)].strval));
                                         cl_free((yyvsp[(3) - (3)].storage).path);
@@ -1718,7 +1718,7 @@ yyreduce:
 
                                         DynArg *a;
 
-                                        sprintf(cregestring, "Dynamic attribute %s declared twice -- "
+                                        snprintf(cregestring, 1024, "Dynamic attribute %s declared twice -- "
                                                 "semantic error", (yyvsp[(2) - (8)].strval));
                                         cl_free((yyvsp[(2) - (8)].strval));
                                         cl_free((yyvsp[(7) - (8)].args));
@@ -1792,7 +1792,7 @@ yyreduce:
 #line 352 "registry.y"
     { (yyval.args) = (DynArg *)makearg((yyvsp[(1) - (1)].strval)); 
                                       if ((yyval.args) == NULL) {
-                                        sprintf(cregestring, "Illegal argument type %s or "
+                                        snprintf(cregestring, 1024, "Illegal argument type %s or "
                                                 "not enough memory -- FATAL ERROR", (yyvsp[(1) - (1)].strval));
                                         cregerror(cregestring);
                                       }
@@ -1867,7 +1867,7 @@ yyreduce:
 #line 389 "registry.y"
     { char *nr;
                                       nr = (char *)cl_malloc(16);
-                                      sprintf(nr, "%d", (yyvsp[(1) - (1)].ival));
+                                      snprintf(nr, 1024, "%d", (yyvsp[(1) - (1)].ival));
                                       (yyval.strval) = nr;
                                     ;}
     break;
