@@ -490,7 +490,7 @@ html_print_group(Group *group, FILE *dest)
     html_puts(dest, target_s, SUBST_ALL);
     Rprintf("<TD>%d</TR>\n", count);
 
-    nr_targets++;
+    nr_targets = nr_targets + 1; /* replaces nr_targets++; #83 */ 
   }
 
   Rprintf("</TABLE>\n</BODY>\n");
