@@ -1,13 +1,13 @@
-/* 
+/*
  *  IMS Open Corpus Workbench (CWB)
  *  Copyright (C) 1993-2006 by IMS, University of Stuttgart
  *  Copyright (C) 2007-     by the respective contributers (see file AUTHORS)
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
  *  Free Software Foundation; either version 2, or (at your option) any later
  *  version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful, but
  *  WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
@@ -15,8 +15,8 @@
  *  WWW at http://www.gnu.org/copyleft/gpl.html).
  */
 
-#ifndef _html_print_h_
-#define _html_print_h_
+#ifndef _cqp_html_print_h_
+#define _cqp_html_print_h_
 
 #include <stdio.h>
 #include "../cl/bitfields.h"
@@ -34,28 +34,15 @@
 
 extern PrintDescriptionRecord HTMLPrintDescriptionRecord;
 
-char *
-html_convert_string(char *s);
+const char *html_convert_string(const char *s);
 
-void 
-html_puts(FILE *fd, char *s, int flags);
+void html_print_aligned_line(FILE *dest, int highlighting, char *attribute_name, char *line);
 
-void
-html_print_aligned_line(FILE *stream, char *attribute_name, char *line);
+void html_print_corpus_header(CorpusList *cl,FILE *dest);
 
-void 
-html_print_corpus_header(CorpusList *cl, 
-			 FILE *outfd);
+void html_print_output(CorpusList *cl, FILE *dest, int interactive,ContextDescriptor *cd, int first, int last);
 
-void 
-html_print_output(CorpusList *cl, 
-		  FILE *outfd,
-		  int interactive,
-		  ContextDescriptor *cd,
-		  int first, int last);
-
-void 
-html_print_group(Group *group, int expand, FILE *fd);
+void html_print_group(Group *group, FILE *dest);
 
 #endif
 
