@@ -1,5 +1,5 @@
 library(RcppCWB)
-
+use_tmp_registry()
 testthat::context("get_count_vector")
 
 test_that(
@@ -8,7 +8,7 @@ test_that(
     Ns <- get_count_vector(
       corpus = "REUTERS",
       p_attribute = "word",
-      registry = use_tmp_registry()
+      registry = get_tmp_registry()
     )
     expect_equal(length(Ns), 1192)
     expect_equal(Ns[16], 78L)
